# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['SSODomainArgs', 'SSODomain']

@pulumi.input_type
class SSODomainArgs:
    def __init__(__self__, *,
                 domain: pulumi.Input[str],
                 sso_config_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a SSODomain resource.
        :param pulumi.Input[str] domain: The domain name for the SSO domain configuration. This domain will be used to validate the SSO configuration and needs to be unique across all SSO configurations.
        :param pulumi.Input[str] sso_config_id: The ID of the associated SSO configuration.
        """
        pulumi.set(__self__, "domain", domain)
        pulumi.set(__self__, "sso_config_id", sso_config_id)

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Input[str]:
        """
        The domain name for the SSO domain configuration. This domain will be used to validate the SSO configuration and needs to be unique across all SSO configurations.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: pulumi.Input[str]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="ssoConfigId")
    def sso_config_id(self) -> pulumi.Input[str]:
        """
        The ID of the associated SSO configuration.
        """
        return pulumi.get(self, "sso_config_id")

    @sso_config_id.setter
    def sso_config_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "sso_config_id", value)


@pulumi.input_type
class _SSODomainState:
    def __init__(__self__, *,
                 domain: Optional[pulumi.Input[str]] = None,
                 sso_config_id: Optional[pulumi.Input[str]] = None,
                 validated: Optional[pulumi.Input[bool]] = None):
        """
        Input properties used for looking up and filtering SSODomain resources.
        :param pulumi.Input[str] domain: The domain name for the SSO domain configuration. This domain will be used to validate the SSO configuration and needs to be unique across all SSO configurations.
        :param pulumi.Input[str] sso_config_id: The ID of the associated SSO configuration.
        :param pulumi.Input[bool] validated: Indicates whether the domain has been validated.
        """
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if sso_config_id is not None:
            pulumi.set(__self__, "sso_config_id", sso_config_id)
        if validated is not None:
            pulumi.set(__self__, "validated", validated)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[str]]:
        """
        The domain name for the SSO domain configuration. This domain will be used to validate the SSO configuration and needs to be unique across all SSO configurations.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="ssoConfigId")
    def sso_config_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the associated SSO configuration.
        """
        return pulumi.get(self, "sso_config_id")

    @sso_config_id.setter
    def sso_config_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sso_config_id", value)

    @property
    @pulumi.getter
    def validated(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether the domain has been validated.
        """
        return pulumi.get(self, "validated")

    @validated.setter
    def validated(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "validated", value)


class SSODomain(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 domain: Optional[pulumi.Input[str]] = None,
                 sso_config_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The SSO domain resource allows you to set the domain for an SSO configuration. This domain will be used to validate the SSO configuration.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_sso_domain = materialize.SSODomain("exampleSsoDomain",
            domain="example.com",
            sso_config_id=materialize_sso_config["example_sso_config"]["id"])
        ```

        ## Import

        The SSO Configuration ID can be found using the `materialize_sso_config` data source

        ```sh
         $ pulumi import materialize:index/sSODomain:SSODomain example <sso_config_id>:<domain.com>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] domain: The domain name for the SSO domain configuration. This domain will be used to validate the SSO configuration and needs to be unique across all SSO configurations.
        :param pulumi.Input[str] sso_config_id: The ID of the associated SSO configuration.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SSODomainArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The SSO domain resource allows you to set the domain for an SSO configuration. This domain will be used to validate the SSO configuration.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_sso_domain = materialize.SSODomain("exampleSsoDomain",
            domain="example.com",
            sso_config_id=materialize_sso_config["example_sso_config"]["id"])
        ```

        ## Import

        The SSO Configuration ID can be found using the `materialize_sso_config` data source

        ```sh
         $ pulumi import materialize:index/sSODomain:SSODomain example <sso_config_id>:<domain.com>
        ```

        :param str resource_name: The name of the resource.
        :param SSODomainArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SSODomainArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 domain: Optional[pulumi.Input[str]] = None,
                 sso_config_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SSODomainArgs.__new__(SSODomainArgs)

            if domain is None and not opts.urn:
                raise TypeError("Missing required property 'domain'")
            __props__.__dict__["domain"] = domain
            if sso_config_id is None and not opts.urn:
                raise TypeError("Missing required property 'sso_config_id'")
            __props__.__dict__["sso_config_id"] = sso_config_id
            __props__.__dict__["validated"] = None
        super(SSODomain, __self__).__init__(
            'materialize:index/sSODomain:SSODomain',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            domain: Optional[pulumi.Input[str]] = None,
            sso_config_id: Optional[pulumi.Input[str]] = None,
            validated: Optional[pulumi.Input[bool]] = None) -> 'SSODomain':
        """
        Get an existing SSODomain resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] domain: The domain name for the SSO domain configuration. This domain will be used to validate the SSO configuration and needs to be unique across all SSO configurations.
        :param pulumi.Input[str] sso_config_id: The ID of the associated SSO configuration.
        :param pulumi.Input[bool] validated: Indicates whether the domain has been validated.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SSODomainState.__new__(_SSODomainState)

        __props__.__dict__["domain"] = domain
        __props__.__dict__["sso_config_id"] = sso_config_id
        __props__.__dict__["validated"] = validated
        return SSODomain(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Output[str]:
        """
        The domain name for the SSO domain configuration. This domain will be used to validate the SSO configuration and needs to be unique across all SSO configurations.
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter(name="ssoConfigId")
    def sso_config_id(self) -> pulumi.Output[str]:
        """
        The ID of the associated SSO configuration.
        """
        return pulumi.get(self, "sso_config_id")

    @property
    @pulumi.getter
    def validated(self) -> pulumi.Output[bool]:
        """
        Indicates whether the domain has been validated.
        """
        return pulumi.get(self, "validated")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'RegionResult',
    'AwaitableRegionResult',
    'region',
]

@pulumi.output_type
class RegionResult:
    """
    A collection of values returned by Region.
    """
    def __init__(__self__, id=None, regions=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if regions and not isinstance(regions, list):
            raise TypeError("Expected argument 'regions' to be a list")
        pulumi.set(__self__, "regions", regions)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def regions(self) -> Sequence['outputs.RegionRegionResult']:
        return pulumi.get(self, "regions")


class AwaitableRegionResult(RegionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return RegionResult(
            id=self.id,
            regions=self.regions)


def region(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableRegionResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_materialize as materialize

    all = materialize.region()
    pulumi.export("region", all)
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('materialize:index/region:Region', __args__, opts=opts, typ=RegionResult).value

    return AwaitableRegionResult(
        id=pulumi.get(__ret__, 'id'),
        regions=pulumi.get(__ret__, 'regions'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['CloudRegionArgs', 'CloudRegion']

@pulumi.input_type
class CloudRegionArgs:
    def __init__(__self__, *,
                 region_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a CloudRegion resource.
        :param pulumi.Input[str] region_id: The ID of the region to manage. Example: aws/us-west-2
        """
        pulumi.set(__self__, "region_id", region_id)

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> pulumi.Input[str]:
        """
        The ID of the region to manage. Example: aws/us-west-2
        """
        return pulumi.get(self, "region_id")

    @region_id.setter
    def region_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "region_id", value)


@pulumi.input_type
class _CloudRegionState:
    def __init__(__self__, *,
                 enabled_at: Optional[pulumi.Input[str]] = None,
                 http_address: Optional[pulumi.Input[str]] = None,
                 region_id: Optional[pulumi.Input[str]] = None,
                 region_state: Optional[pulumi.Input[bool]] = None,
                 resolvable: Optional[pulumi.Input[bool]] = None,
                 sql_address: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering CloudRegion resources.
        :param pulumi.Input[str] enabled_at: The timestamp when the region was enabled.
        :param pulumi.Input[str] http_address: The HTTP address of the region.
        :param pulumi.Input[str] region_id: The ID of the region to manage. Example: aws/us-west-2
        :param pulumi.Input[bool] region_state: The state of the region. True if enabled, false otherwise.
        :param pulumi.Input[bool] resolvable: Indicates if the region is resolvable.
        :param pulumi.Input[str] sql_address: The SQL address of the region.
        """
        if enabled_at is not None:
            pulumi.set(__self__, "enabled_at", enabled_at)
        if http_address is not None:
            pulumi.set(__self__, "http_address", http_address)
        if region_id is not None:
            pulumi.set(__self__, "region_id", region_id)
        if region_state is not None:
            pulumi.set(__self__, "region_state", region_state)
        if resolvable is not None:
            pulumi.set(__self__, "resolvable", resolvable)
        if sql_address is not None:
            pulumi.set(__self__, "sql_address", sql_address)

    @property
    @pulumi.getter(name="enabledAt")
    def enabled_at(self) -> Optional[pulumi.Input[str]]:
        """
        The timestamp when the region was enabled.
        """
        return pulumi.get(self, "enabled_at")

    @enabled_at.setter
    def enabled_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "enabled_at", value)

    @property
    @pulumi.getter(name="httpAddress")
    def http_address(self) -> Optional[pulumi.Input[str]]:
        """
        The HTTP address of the region.
        """
        return pulumi.get(self, "http_address")

    @http_address.setter
    def http_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "http_address", value)

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the region to manage. Example: aws/us-west-2
        """
        return pulumi.get(self, "region_id")

    @region_id.setter
    def region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region_id", value)

    @property
    @pulumi.getter(name="regionState")
    def region_state(self) -> Optional[pulumi.Input[bool]]:
        """
        The state of the region. True if enabled, false otherwise.
        """
        return pulumi.get(self, "region_state")

    @region_state.setter
    def region_state(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "region_state", value)

    @property
    @pulumi.getter
    def resolvable(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates if the region is resolvable.
        """
        return pulumi.get(self, "resolvable")

    @resolvable.setter
    def resolvable(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "resolvable", value)

    @property
    @pulumi.getter(name="sqlAddress")
    def sql_address(self) -> Optional[pulumi.Input[str]]:
        """
        The SQL address of the region.
        """
        return pulumi.get(self, "sql_address")

    @sql_address.setter
    def sql_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sql_address", value)


class CloudRegion(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 region_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The region resource allows you to manage regions in Materialize. When a new region is created, it automatically includes an 'xsmall' quickstart cluster as part of the initialization process. Users are billed for this quickstart cluster from the moment the region is created. To avoid unnecessary charges, you can connect to the new region and drop the quickstart cluster if it is not needed. Please note that disabling a region cannot be achieved directly through this provider. If you need to disable a region, contact Materialize support for assistance. This process ensures that any necessary cleanup and billing adjustments are handled properly.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example = materialize.CloudRegion("example", region_id="aws/us-east-1")
        ```

        ## Import

        ```sh
         $ pulumi import materialize:index/cloudRegion:CloudRegion Regions can be imported using the `terraform import` command
        ```

        ```sh
         $ pulumi import materialize:index/cloudRegion:CloudRegion example_region aws/us-east-1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] region_id: The ID of the region to manage. Example: aws/us-west-2
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CloudRegionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The region resource allows you to manage regions in Materialize. When a new region is created, it automatically includes an 'xsmall' quickstart cluster as part of the initialization process. Users are billed for this quickstart cluster from the moment the region is created. To avoid unnecessary charges, you can connect to the new region and drop the quickstart cluster if it is not needed. Please note that disabling a region cannot be achieved directly through this provider. If you need to disable a region, contact Materialize support for assistance. This process ensures that any necessary cleanup and billing adjustments are handled properly.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example = materialize.CloudRegion("example", region_id="aws/us-east-1")
        ```

        ## Import

        ```sh
         $ pulumi import materialize:index/cloudRegion:CloudRegion Regions can be imported using the `terraform import` command
        ```

        ```sh
         $ pulumi import materialize:index/cloudRegion:CloudRegion example_region aws/us-east-1
        ```

        :param str resource_name: The name of the resource.
        :param CloudRegionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CloudRegionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 region_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CloudRegionArgs.__new__(CloudRegionArgs)

            if region_id is None and not opts.urn:
                raise TypeError("Missing required property 'region_id'")
            __props__.__dict__["region_id"] = region_id
            __props__.__dict__["enabled_at"] = None
            __props__.__dict__["http_address"] = None
            __props__.__dict__["region_state"] = None
            __props__.__dict__["resolvable"] = None
            __props__.__dict__["sql_address"] = None
        super(CloudRegion, __self__).__init__(
            'materialize:index/cloudRegion:CloudRegion',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            enabled_at: Optional[pulumi.Input[str]] = None,
            http_address: Optional[pulumi.Input[str]] = None,
            region_id: Optional[pulumi.Input[str]] = None,
            region_state: Optional[pulumi.Input[bool]] = None,
            resolvable: Optional[pulumi.Input[bool]] = None,
            sql_address: Optional[pulumi.Input[str]] = None) -> 'CloudRegion':
        """
        Get an existing CloudRegion resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] enabled_at: The timestamp when the region was enabled.
        :param pulumi.Input[str] http_address: The HTTP address of the region.
        :param pulumi.Input[str] region_id: The ID of the region to manage. Example: aws/us-west-2
        :param pulumi.Input[bool] region_state: The state of the region. True if enabled, false otherwise.
        :param pulumi.Input[bool] resolvable: Indicates if the region is resolvable.
        :param pulumi.Input[str] sql_address: The SQL address of the region.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CloudRegionState.__new__(_CloudRegionState)

        __props__.__dict__["enabled_at"] = enabled_at
        __props__.__dict__["http_address"] = http_address
        __props__.__dict__["region_id"] = region_id
        __props__.__dict__["region_state"] = region_state
        __props__.__dict__["resolvable"] = resolvable
        __props__.__dict__["sql_address"] = sql_address
        return CloudRegion(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="enabledAt")
    def enabled_at(self) -> pulumi.Output[str]:
        """
        The timestamp when the region was enabled.
        """
        return pulumi.get(self, "enabled_at")

    @property
    @pulumi.getter(name="httpAddress")
    def http_address(self) -> pulumi.Output[str]:
        """
        The HTTP address of the region.
        """
        return pulumi.get(self, "http_address")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> pulumi.Output[str]:
        """
        The ID of the region to manage. Example: aws/us-west-2
        """
        return pulumi.get(self, "region_id")

    @property
    @pulumi.getter(name="regionState")
    def region_state(self) -> pulumi.Output[bool]:
        """
        The state of the region. True if enabled, false otherwise.
        """
        return pulumi.get(self, "region_state")

    @property
    @pulumi.getter
    def resolvable(self) -> pulumi.Output[bool]:
        """
        Indicates if the region is resolvable.
        """
        return pulumi.get(self, "resolvable")

    @property
    @pulumi.getter(name="sqlAddress")
    def sql_address(self) -> pulumi.Output[str]:
        """
        The SQL address of the region.
        """
        return pulumi.get(self, "sql_address")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ConnectionAwsArgs', 'ConnectionAws']

@pulumi.input_type
class ConnectionAwsArgs:
    def __init__(__self__, *,
                 access_key_id: Optional[pulumi.Input['ConnectionAwsAccessKeyIdArgs']] = None,
                 assume_role_arn: Optional[pulumi.Input[str]] = None,
                 assume_role_session_name: Optional[pulumi.Input[str]] = None,
                 aws_region: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 endpoint: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 secret_access_key: Optional[pulumi.Input['ConnectionAwsSecretAccessKeyArgs']] = None,
                 session_token: Optional[pulumi.Input['ConnectionAwsSessionTokenArgs']] = None,
                 validate: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a ConnectionAws resource.
        :param pulumi.Input['ConnectionAwsAccessKeyIdArgs'] access_key_id: The access key ID to connect with.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input[str] assume_role_arn: The Amazon Resource Name (ARN) of the IAM role to assume.
        :param pulumi.Input[str] assume_role_session_name: The session name to use when assuming the role.
        :param pulumi.Input[str] aws_region: The AWS region to connect to.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the connection database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[str] endpoint: Override the default AWS endpoint URL.
        :param pulumi.Input[str] name: The identifier for the connection.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the connection schema in Materialize. Defaults to `public`.
        :param pulumi.Input['ConnectionAwsSecretAccessKeyArgs'] secret_access_key: The secret access key corresponding to the specified access key ID.
        :param pulumi.Input['ConnectionAwsSessionTokenArgs'] session_token: The session token corresponding to the specified access key ID.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input[bool] validate: **Private Preview** If the connection should wait for validation.
        """
        if access_key_id is not None:
            pulumi.set(__self__, "access_key_id", access_key_id)
        if assume_role_arn is not None:
            pulumi.set(__self__, "assume_role_arn", assume_role_arn)
        if assume_role_session_name is not None:
            pulumi.set(__self__, "assume_role_session_name", assume_role_session_name)
        if aws_region is not None:
            pulumi.set(__self__, "aws_region", aws_region)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if endpoint is not None:
            pulumi.set(__self__, "endpoint", endpoint)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if ownership_role is not None:
            pulumi.set(__self__, "ownership_role", ownership_role)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if schema_name is not None:
            pulumi.set(__self__, "schema_name", schema_name)
        if secret_access_key is not None:
            pulumi.set(__self__, "secret_access_key", secret_access_key)
        if session_token is not None:
            pulumi.set(__self__, "session_token", session_token)
        if validate is not None:
            pulumi.set(__self__, "validate", validate)

    @property
    @pulumi.getter(name="accessKeyId")
    def access_key_id(self) -> Optional[pulumi.Input['ConnectionAwsAccessKeyIdArgs']]:
        """
        The access key ID to connect with.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        """
        return pulumi.get(self, "access_key_id")

    @access_key_id.setter
    def access_key_id(self, value: Optional[pulumi.Input['ConnectionAwsAccessKeyIdArgs']]):
        pulumi.set(self, "access_key_id", value)

    @property
    @pulumi.getter(name="assumeRoleArn")
    def assume_role_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The Amazon Resource Name (ARN) of the IAM role to assume.
        """
        return pulumi.get(self, "assume_role_arn")

    @assume_role_arn.setter
    def assume_role_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "assume_role_arn", value)

    @property
    @pulumi.getter(name="assumeRoleSessionName")
    def assume_role_session_name(self) -> Optional[pulumi.Input[str]]:
        """
        The session name to use when assuming the role.
        """
        return pulumi.get(self, "assume_role_session_name")

    @assume_role_session_name.setter
    def assume_role_session_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "assume_role_session_name", value)

    @property
    @pulumi.getter(name="awsRegion")
    def aws_region(self) -> Optional[pulumi.Input[str]]:
        """
        The AWS region to connect to.
        """
        return pulumi.get(self, "aws_region")

    @aws_region.setter
    def aws_region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "aws_region", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the connection database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter
    def endpoint(self) -> Optional[pulumi.Input[str]]:
        """
        Override the default AWS endpoint URL.
        """
        return pulumi.get(self, "endpoint")

    @endpoint.setter
    def endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "endpoint", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the connection.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> Optional[pulumi.Input[str]]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @ownership_role.setter
    def ownership_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ownership_role", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the connection schema in Materialize. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schema_name", value)

    @property
    @pulumi.getter(name="secretAccessKey")
    def secret_access_key(self) -> Optional[pulumi.Input['ConnectionAwsSecretAccessKeyArgs']]:
        """
        The secret access key corresponding to the specified access key ID.
        """
        return pulumi.get(self, "secret_access_key")

    @secret_access_key.setter
    def secret_access_key(self, value: Optional[pulumi.Input['ConnectionAwsSecretAccessKeyArgs']]):
        pulumi.set(self, "secret_access_key", value)

    @property
    @pulumi.getter(name="sessionToken")
    def session_token(self) -> Optional[pulumi.Input['ConnectionAwsSessionTokenArgs']]:
        """
        The session token corresponding to the specified access key ID.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        """
        return pulumi.get(self, "session_token")

    @session_token.setter
    def session_token(self, value: Optional[pulumi.Input['ConnectionAwsSessionTokenArgs']]):
        pulumi.set(self, "session_token", value)

    @property
    @pulumi.getter
    def validate(self) -> Optional[pulumi.Input[bool]]:
        """
        **Private Preview** If the connection should wait for validation.
        """
        return pulumi.get(self, "validate")

    @validate.setter
    def validate(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "validate", value)


@pulumi.input_type
class _ConnectionAwsState:
    def __init__(__self__, *,
                 access_key_id: Optional[pulumi.Input['ConnectionAwsAccessKeyIdArgs']] = None,
                 assume_role_arn: Optional[pulumi.Input[str]] = None,
                 assume_role_session_name: Optional[pulumi.Input[str]] = None,
                 aws_region: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 endpoint: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 qualified_sql_name: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 secret_access_key: Optional[pulumi.Input['ConnectionAwsSecretAccessKeyArgs']] = None,
                 session_token: Optional[pulumi.Input['ConnectionAwsSessionTokenArgs']] = None,
                 validate: Optional[pulumi.Input[bool]] = None):
        """
        Input properties used for looking up and filtering ConnectionAws resources.
        :param pulumi.Input['ConnectionAwsAccessKeyIdArgs'] access_key_id: The access key ID to connect with.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input[str] assume_role_arn: The Amazon Resource Name (ARN) of the IAM role to assume.
        :param pulumi.Input[str] assume_role_session_name: The session name to use when assuming the role.
        :param pulumi.Input[str] aws_region: The AWS region to connect to.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the connection database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[str] endpoint: Override the default AWS endpoint URL.
        :param pulumi.Input[str] name: The identifier for the connection.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] qualified_sql_name: The fully qualified name of the connection.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the connection schema in Materialize. Defaults to `public`.
        :param pulumi.Input['ConnectionAwsSecretAccessKeyArgs'] secret_access_key: The secret access key corresponding to the specified access key ID.
        :param pulumi.Input['ConnectionAwsSessionTokenArgs'] session_token: The session token corresponding to the specified access key ID.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input[bool] validate: **Private Preview** If the connection should wait for validation.
        """
        if access_key_id is not None:
            pulumi.set(__self__, "access_key_id", access_key_id)
        if assume_role_arn is not None:
            pulumi.set(__self__, "assume_role_arn", assume_role_arn)
        if assume_role_session_name is not None:
            pulumi.set(__self__, "assume_role_session_name", assume_role_session_name)
        if aws_region is not None:
            pulumi.set(__self__, "aws_region", aws_region)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if endpoint is not None:
            pulumi.set(__self__, "endpoint", endpoint)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if ownership_role is not None:
            pulumi.set(__self__, "ownership_role", ownership_role)
        if qualified_sql_name is not None:
            pulumi.set(__self__, "qualified_sql_name", qualified_sql_name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if schema_name is not None:
            pulumi.set(__self__, "schema_name", schema_name)
        if secret_access_key is not None:
            pulumi.set(__self__, "secret_access_key", secret_access_key)
        if session_token is not None:
            pulumi.set(__self__, "session_token", session_token)
        if validate is not None:
            pulumi.set(__self__, "validate", validate)

    @property
    @pulumi.getter(name="accessKeyId")
    def access_key_id(self) -> Optional[pulumi.Input['ConnectionAwsAccessKeyIdArgs']]:
        """
        The access key ID to connect with.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        """
        return pulumi.get(self, "access_key_id")

    @access_key_id.setter
    def access_key_id(self, value: Optional[pulumi.Input['ConnectionAwsAccessKeyIdArgs']]):
        pulumi.set(self, "access_key_id", value)

    @property
    @pulumi.getter(name="assumeRoleArn")
    def assume_role_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The Amazon Resource Name (ARN) of the IAM role to assume.
        """
        return pulumi.get(self, "assume_role_arn")

    @assume_role_arn.setter
    def assume_role_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "assume_role_arn", value)

    @property
    @pulumi.getter(name="assumeRoleSessionName")
    def assume_role_session_name(self) -> Optional[pulumi.Input[str]]:
        """
        The session name to use when assuming the role.
        """
        return pulumi.get(self, "assume_role_session_name")

    @assume_role_session_name.setter
    def assume_role_session_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "assume_role_session_name", value)

    @property
    @pulumi.getter(name="awsRegion")
    def aws_region(self) -> Optional[pulumi.Input[str]]:
        """
        The AWS region to connect to.
        """
        return pulumi.get(self, "aws_region")

    @aws_region.setter
    def aws_region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "aws_region", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the connection database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter
    def endpoint(self) -> Optional[pulumi.Input[str]]:
        """
        Override the default AWS endpoint URL.
        """
        return pulumi.get(self, "endpoint")

    @endpoint.setter
    def endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "endpoint", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the connection.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> Optional[pulumi.Input[str]]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @ownership_role.setter
    def ownership_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ownership_role", value)

    @property
    @pulumi.getter(name="qualifiedSqlName")
    def qualified_sql_name(self) -> Optional[pulumi.Input[str]]:
        """
        The fully qualified name of the connection.
        """
        return pulumi.get(self, "qualified_sql_name")

    @qualified_sql_name.setter
    def qualified_sql_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "qualified_sql_name", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the connection schema in Materialize. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schema_name", value)

    @property
    @pulumi.getter(name="secretAccessKey")
    def secret_access_key(self) -> Optional[pulumi.Input['ConnectionAwsSecretAccessKeyArgs']]:
        """
        The secret access key corresponding to the specified access key ID.
        """
        return pulumi.get(self, "secret_access_key")

    @secret_access_key.setter
    def secret_access_key(self, value: Optional[pulumi.Input['ConnectionAwsSecretAccessKeyArgs']]):
        pulumi.set(self, "secret_access_key", value)

    @property
    @pulumi.getter(name="sessionToken")
    def session_token(self) -> Optional[pulumi.Input['ConnectionAwsSessionTokenArgs']]:
        """
        The session token corresponding to the specified access key ID.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        """
        return pulumi.get(self, "session_token")

    @session_token.setter
    def session_token(self, value: Optional[pulumi.Input['ConnectionAwsSessionTokenArgs']]):
        pulumi.set(self, "session_token", value)

    @property
    @pulumi.getter
    def validate(self) -> Optional[pulumi.Input[bool]]:
        """
        **Private Preview** If the connection should wait for validation.
        """
        return pulumi.get(self, "validate")

    @validate.setter
    def validate(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "validate", value)


class ConnectionAws(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_key_id: Optional[pulumi.Input[pulumi.InputType['ConnectionAwsAccessKeyIdArgs']]] = None,
                 assume_role_arn: Optional[pulumi.Input[str]] = None,
                 assume_role_session_name: Optional[pulumi.Input[str]] = None,
                 aws_region: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 endpoint: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 secret_access_key: Optional[pulumi.Input[pulumi.InputType['ConnectionAwsSecretAccessKeyArgs']]] = None,
                 session_token: Optional[pulumi.Input[pulumi.InputType['ConnectionAwsSessionTokenArgs']]] = None,
                 validate: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        An Amazon Web Services (AWS) connection provides Materialize with access to an Identity and Access Management (IAM) user or role in your AWS account.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        # Create a AWS Connection
        example_connection = materialize.ConnectionAws("exampleConnection",
            access_key_id="foo",
            schema_name="public",
            secret_access_key="bar")
        ```

        ## Import

        #Connections can be imported using the connection id

        ```sh
         $ pulumi import materialize:index/connectionAws:ConnectionAws example <region>:<connection_id>
        ```

         Connection id and information be found in the `mz_catalog.mz_connections` table The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['ConnectionAwsAccessKeyIdArgs']] access_key_id: The access key ID to connect with.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input[str] assume_role_arn: The Amazon Resource Name (ARN) of the IAM role to assume.
        :param pulumi.Input[str] assume_role_session_name: The session name to use when assuming the role.
        :param pulumi.Input[str] aws_region: The AWS region to connect to.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the connection database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[str] endpoint: Override the default AWS endpoint URL.
        :param pulumi.Input[str] name: The identifier for the connection.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the connection schema in Materialize. Defaults to `public`.
        :param pulumi.Input[pulumi.InputType['ConnectionAwsSecretAccessKeyArgs']] secret_access_key: The secret access key corresponding to the specified access key ID.
        :param pulumi.Input[pulumi.InputType['ConnectionAwsSessionTokenArgs']] session_token: The session token corresponding to the specified access key ID.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input[bool] validate: **Private Preview** If the connection should wait for validation.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ConnectionAwsArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        An Amazon Web Services (AWS) connection provides Materialize with access to an Identity and Access Management (IAM) user or role in your AWS account.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        # Create a AWS Connection
        example_connection = materialize.ConnectionAws("exampleConnection",
            access_key_id="foo",
            schema_name="public",
            secret_access_key="bar")
        ```

        ## Import

        #Connections can be imported using the connection id

        ```sh
         $ pulumi import materialize:index/connectionAws:ConnectionAws example <region>:<connection_id>
        ```

         Connection id and information be found in the `mz_catalog.mz_connections` table The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param ConnectionAwsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConnectionAwsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_key_id: Optional[pulumi.Input[pulumi.InputType['ConnectionAwsAccessKeyIdArgs']]] = None,
                 assume_role_arn: Optional[pulumi.Input[str]] = None,
                 assume_role_session_name: Optional[pulumi.Input[str]] = None,
                 aws_region: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 endpoint: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 secret_access_key: Optional[pulumi.Input[pulumi.InputType['ConnectionAwsSecretAccessKeyArgs']]] = None,
                 session_token: Optional[pulumi.Input[pulumi.InputType['ConnectionAwsSessionTokenArgs']]] = None,
                 validate: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConnectionAwsArgs.__new__(ConnectionAwsArgs)

            __props__.__dict__["access_key_id"] = access_key_id
            __props__.__dict__["assume_role_arn"] = assume_role_arn
            __props__.__dict__["assume_role_session_name"] = assume_role_session_name
            __props__.__dict__["aws_region"] = aws_region
            __props__.__dict__["comment"] = comment
            __props__.__dict__["database_name"] = database_name
            __props__.__dict__["endpoint"] = endpoint
            __props__.__dict__["name"] = name
            __props__.__dict__["ownership_role"] = ownership_role
            __props__.__dict__["region"] = region
            __props__.__dict__["schema_name"] = schema_name
            __props__.__dict__["secret_access_key"] = secret_access_key
            __props__.__dict__["session_token"] = session_token
            __props__.__dict__["validate"] = validate
            __props__.__dict__["qualified_sql_name"] = None
        super(ConnectionAws, __self__).__init__(
            'materialize:index/connectionAws:ConnectionAws',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_key_id: Optional[pulumi.Input[pulumi.InputType['ConnectionAwsAccessKeyIdArgs']]] = None,
            assume_role_arn: Optional[pulumi.Input[str]] = None,
            assume_role_session_name: Optional[pulumi.Input[str]] = None,
            aws_region: Optional[pulumi.Input[str]] = None,
            comment: Optional[pulumi.Input[str]] = None,
            database_name: Optional[pulumi.Input[str]] = None,
            endpoint: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            ownership_role: Optional[pulumi.Input[str]] = None,
            qualified_sql_name: Optional[pulumi.Input[str]] = None,
            region: Optional[pulumi.Input[str]] = None,
            schema_name: Optional[pulumi.Input[str]] = None,
            secret_access_key: Optional[pulumi.Input[pulumi.InputType['ConnectionAwsSecretAccessKeyArgs']]] = None,
            session_token: Optional[pulumi.Input[pulumi.InputType['ConnectionAwsSessionTokenArgs']]] = None,
            validate: Optional[pulumi.Input[bool]] = None) -> 'ConnectionAws':
        """
        Get an existing ConnectionAws resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['ConnectionAwsAccessKeyIdArgs']] access_key_id: The access key ID to connect with.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input[str] assume_role_arn: The Amazon Resource Name (ARN) of the IAM role to assume.
        :param pulumi.Input[str] assume_role_session_name: The session name to use when assuming the role.
        :param pulumi.Input[str] aws_region: The AWS region to connect to.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the connection database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[str] endpoint: Override the default AWS endpoint URL.
        :param pulumi.Input[str] name: The identifier for the connection.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] qualified_sql_name: The fully qualified name of the connection.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the connection schema in Materialize. Defaults to `public`.
        :param pulumi.Input[pulumi.InputType['ConnectionAwsSecretAccessKeyArgs']] secret_access_key: The secret access key corresponding to the specified access key ID.
        :param pulumi.Input[pulumi.InputType['ConnectionAwsSessionTokenArgs']] session_token: The session token corresponding to the specified access key ID.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input[bool] validate: **Private Preview** If the connection should wait for validation.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConnectionAwsState.__new__(_ConnectionAwsState)

        __props__.__dict__["access_key_id"] = access_key_id
        __props__.__dict__["assume_role_arn"] = assume_role_arn
        __props__.__dict__["assume_role_session_name"] = assume_role_session_name
        __props__.__dict__["aws_region"] = aws_region
        __props__.__dict__["comment"] = comment
        __props__.__dict__["database_name"] = database_name
        __props__.__dict__["endpoint"] = endpoint
        __props__.__dict__["name"] = name
        __props__.__dict__["ownership_role"] = ownership_role
        __props__.__dict__["qualified_sql_name"] = qualified_sql_name
        __props__.__dict__["region"] = region
        __props__.__dict__["schema_name"] = schema_name
        __props__.__dict__["secret_access_key"] = secret_access_key
        __props__.__dict__["session_token"] = session_token
        __props__.__dict__["validate"] = validate
        return ConnectionAws(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accessKeyId")
    def access_key_id(self) -> pulumi.Output[Optional['outputs.ConnectionAwsAccessKeyId']]:
        """
        The access key ID to connect with.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        """
        return pulumi.get(self, "access_key_id")

    @property
    @pulumi.getter(name="assumeRoleArn")
    def assume_role_arn(self) -> pulumi.Output[Optional[str]]:
        """
        The Amazon Resource Name (ARN) of the IAM role to assume.
        """
        return pulumi.get(self, "assume_role_arn")

    @property
    @pulumi.getter(name="assumeRoleSessionName")
    def assume_role_session_name(self) -> pulumi.Output[Optional[str]]:
        """
        The session name to use when assuming the role.
        """
        return pulumi.get(self, "assume_role_session_name")

    @property
    @pulumi.getter(name="awsRegion")
    def aws_region(self) -> pulumi.Output[Optional[str]]:
        """
        The AWS region to connect to.
        """
        return pulumi.get(self, "aws_region")

    @property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> pulumi.Output[Optional[str]]:
        """
        The identifier for the connection database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @property
    @pulumi.getter
    def endpoint(self) -> pulumi.Output[Optional[str]]:
        """
        Override the default AWS endpoint URL.
        """
        return pulumi.get(self, "endpoint")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The identifier for the connection.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> pulumi.Output[str]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @property
    @pulumi.getter(name="qualifiedSqlName")
    def qualified_sql_name(self) -> pulumi.Output[str]:
        """
        The fully qualified name of the connection.
        """
        return pulumi.get(self, "qualified_sql_name")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[str]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> pulumi.Output[Optional[str]]:
        """
        The identifier for the connection schema in Materialize. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @property
    @pulumi.getter(name="secretAccessKey")
    def secret_access_key(self) -> pulumi.Output[Optional['outputs.ConnectionAwsSecretAccessKey']]:
        """
        The secret access key corresponding to the specified access key ID.
        """
        return pulumi.get(self, "secret_access_key")

    @property
    @pulumi.getter(name="sessionToken")
    def session_token(self) -> pulumi.Output[Optional['outputs.ConnectionAwsSessionToken']]:
        """
        The session token corresponding to the specified access key ID.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        """
        return pulumi.get(self, "session_token")

    @property
    @pulumi.getter
    def validate(self) -> pulumi.Output[Optional[bool]]:
        """
        **Private Preview** If the connection should wait for validation.
        """
        return pulumi.get(self, "validate")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['SCIM2ConfigurationArgs', 'SCIM2Configuration']

@pulumi.input_type
class SCIM2ConfigurationArgs:
    def __init__(__self__, *,
                 connection_name: pulumi.Input[str],
                 source: pulumi.Input[str]):
        """
        The set of arguments for constructing a SCIM2Configuration resource.
        :param pulumi.Input[str] connection_name: The name of the SCIM 2.0 connection. It must be unique.
        :param pulumi.Input[str] source: The source of the SCIM 2.0 configuration. Supported values are `okta`, `azure-ad`, and `other`.
        """
        pulumi.set(__self__, "connection_name", connection_name)
        pulumi.set(__self__, "source", source)

    @property
    @pulumi.getter(name="connectionName")
    def connection_name(self) -> pulumi.Input[str]:
        """
        The name of the SCIM 2.0 connection. It must be unique.
        """
        return pulumi.get(self, "connection_name")

    @connection_name.setter
    def connection_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "connection_name", value)

    @property
    @pulumi.getter
    def source(self) -> pulumi.Input[str]:
        """
        The source of the SCIM 2.0 configuration. Supported values are `okta`, `azure-ad`, and `other`.
        """
        return pulumi.get(self, "source")

    @source.setter
    def source(self, value: pulumi.Input[str]):
        pulumi.set(self, "source", value)


@pulumi.input_type
class _SCIM2ConfigurationState:
    def __init__(__self__, *,
                 connection_name: Optional[pulumi.Input[str]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 provisioning_url: Optional[pulumi.Input[str]] = None,
                 source: Optional[pulumi.Input[str]] = None,
                 sync_to_user_management: Optional[pulumi.Input[bool]] = None,
                 tenant_id: Optional[pulumi.Input[str]] = None,
                 token: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SCIM2Configuration resources.
        :param pulumi.Input[str] connection_name: The name of the SCIM 2.0 connection. It must be unique.
        :param pulumi.Input[str] created_at: The creation timestamp of the SCIM 2.0 configuration.
        :param pulumi.Input[str] provisioning_url: The provisioning URL of the SCIM 2.0 configuration.
        :param pulumi.Input[str] source: The source of the SCIM 2.0 configuration. Supported values are `okta`, `azure-ad`, and `other`.
        :param pulumi.Input[bool] sync_to_user_management: Indicates whether automatic synchronization of data with the IdP is enabled, ensuring that changes in details or status in the IdP are updated accordingly.
        :param pulumi.Input[str] token: The token of the SCIM 2.0 configuration.
        """
        if connection_name is not None:
            pulumi.set(__self__, "connection_name", connection_name)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if provisioning_url is not None:
            pulumi.set(__self__, "provisioning_url", provisioning_url)
        if source is not None:
            pulumi.set(__self__, "source", source)
        if sync_to_user_management is not None:
            pulumi.set(__self__, "sync_to_user_management", sync_to_user_management)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)
        if token is not None:
            pulumi.set(__self__, "token", token)

    @property
    @pulumi.getter(name="connectionName")
    def connection_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the SCIM 2.0 connection. It must be unique.
        """
        return pulumi.get(self, "connection_name")

    @connection_name.setter
    def connection_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "connection_name", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        The creation timestamp of the SCIM 2.0 configuration.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="provisioningUrl")
    def provisioning_url(self) -> Optional[pulumi.Input[str]]:
        """
        The provisioning URL of the SCIM 2.0 configuration.
        """
        return pulumi.get(self, "provisioning_url")

    @provisioning_url.setter
    def provisioning_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "provisioning_url", value)

    @property
    @pulumi.getter
    def source(self) -> Optional[pulumi.Input[str]]:
        """
        The source of the SCIM 2.0 configuration. Supported values are `okta`, `azure-ad`, and `other`.
        """
        return pulumi.get(self, "source")

    @source.setter
    def source(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source", value)

    @property
    @pulumi.getter(name="syncToUserManagement")
    def sync_to_user_management(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether automatic synchronization of data with the IdP is enabled, ensuring that changes in details or status in the IdP are updated accordingly.
        """
        return pulumi.get(self, "sync_to_user_management")

    @sync_to_user_management.setter
    def sync_to_user_management(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "sync_to_user_management", value)

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_id", value)

    @property
    @pulumi.getter
    def token(self) -> Optional[pulumi.Input[str]]:
        """
        The token of the SCIM 2.0 configuration.
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "token", value)


class SCIM2Configuration(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 connection_name: Optional[pulumi.Input[str]] = None,
                 source: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The SCIM 2.0 configurations resource allows you to create, read, and delete the SCIM 2.0 configurations.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        # Create a SCIM config
        example_scim_config = materialize.SCIM2Configuration("exampleScimConfig",
            connection_name="example_connection",
            source="okta")
        ```

        ## Import

        SCIM Configuration ID can be found using the `materialize_scim_configs` data source

        ```sh
         $ pulumi import materialize:index/sCIM2Configuration:SCIM2Configuration example_scim_config <scim_config_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] connection_name: The name of the SCIM 2.0 connection. It must be unique.
        :param pulumi.Input[str] source: The source of the SCIM 2.0 configuration. Supported values are `okta`, `azure-ad`, and `other`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SCIM2ConfigurationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The SCIM 2.0 configurations resource allows you to create, read, and delete the SCIM 2.0 configurations.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        # Create a SCIM config
        example_scim_config = materialize.SCIM2Configuration("exampleScimConfig",
            connection_name="example_connection",
            source="okta")
        ```

        ## Import

        SCIM Configuration ID can be found using the `materialize_scim_configs` data source

        ```sh
         $ pulumi import materialize:index/sCIM2Configuration:SCIM2Configuration example_scim_config <scim_config_id>
        ```

        :param str resource_name: The name of the resource.
        :param SCIM2ConfigurationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SCIM2ConfigurationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 connection_name: Optional[pulumi.Input[str]] = None,
                 source: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SCIM2ConfigurationArgs.__new__(SCIM2ConfigurationArgs)

            if connection_name is None and not opts.urn:
                raise TypeError("Missing required property 'connection_name'")
            __props__.__dict__["connection_name"] = connection_name
            if source is None and not opts.urn:
                raise TypeError("Missing required property 'source'")
            __props__.__dict__["source"] = source
            __props__.__dict__["created_at"] = None
            __props__.__dict__["provisioning_url"] = None
            __props__.__dict__["sync_to_user_management"] = None
            __props__.__dict__["tenant_id"] = None
            __props__.__dict__["token"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["provisioningUrl", "token"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(SCIM2Configuration, __self__).__init__(
            'materialize:index/sCIM2Configuration:SCIM2Configuration',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            connection_name: Optional[pulumi.Input[str]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            provisioning_url: Optional[pulumi.Input[str]] = None,
            source: Optional[pulumi.Input[str]] = None,
            sync_to_user_management: Optional[pulumi.Input[bool]] = None,
            tenant_id: Optional[pulumi.Input[str]] = None,
            token: Optional[pulumi.Input[str]] = None) -> 'SCIM2Configuration':
        """
        Get an existing SCIM2Configuration resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] connection_name: The name of the SCIM 2.0 connection. It must be unique.
        :param pulumi.Input[str] created_at: The creation timestamp of the SCIM 2.0 configuration.
        :param pulumi.Input[str] provisioning_url: The provisioning URL of the SCIM 2.0 configuration.
        :param pulumi.Input[str] source: The source of the SCIM 2.0 configuration. Supported values are `okta`, `azure-ad`, and `other`.
        :param pulumi.Input[bool] sync_to_user_management: Indicates whether automatic synchronization of data with the IdP is enabled, ensuring that changes in details or status in the IdP are updated accordingly.
        :param pulumi.Input[str] token: The token of the SCIM 2.0 configuration.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SCIM2ConfigurationState.__new__(_SCIM2ConfigurationState)

        __props__.__dict__["connection_name"] = connection_name
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["provisioning_url"] = provisioning_url
        __props__.__dict__["source"] = source
        __props__.__dict__["sync_to_user_management"] = sync_to_user_management
        __props__.__dict__["tenant_id"] = tenant_id
        __props__.__dict__["token"] = token
        return SCIM2Configuration(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="connectionName")
    def connection_name(self) -> pulumi.Output[str]:
        """
        The name of the SCIM 2.0 connection. It must be unique.
        """
        return pulumi.get(self, "connection_name")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        The creation timestamp of the SCIM 2.0 configuration.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="provisioningUrl")
    def provisioning_url(self) -> pulumi.Output[str]:
        """
        The provisioning URL of the SCIM 2.0 configuration.
        """
        return pulumi.get(self, "provisioning_url")

    @property
    @pulumi.getter
    def source(self) -> pulumi.Output[str]:
        """
        The source of the SCIM 2.0 configuration. Supported values are `okta`, `azure-ad`, and `other`.
        """
        return pulumi.get(self, "source")

    @property
    @pulumi.getter(name="syncToUserManagement")
    def sync_to_user_management(self) -> pulumi.Output[bool]:
        """
        Indicates whether automatic synchronization of data with the IdP is enabled, ensuring that changes in details or status in the IdP are updated accordingly.
        """
        return pulumi.get(self, "sync_to_user_management")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "tenant_id")

    @property
    @pulumi.getter
    def token(self) -> pulumi.Output[str]:
        """
        The token of the SCIM 2.0 configuration.
        """
        return pulumi.get(self, "token")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetSourcesResult',
    'AwaitableGetSourcesResult',
    'get_sources',
    'get_sources_output',
]

@pulumi.output_type
class GetSourcesResult:
    """
    A collection of values returned by GetSources.
    """
    def __init__(__self__, database_name=None, id=None, region=None, schema_name=None, sources=None):
        if database_name and not isinstance(database_name, str):
            raise TypeError("Expected argument 'database_name' to be a str")
        pulumi.set(__self__, "database_name", database_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if schema_name and not isinstance(schema_name, str):
            raise TypeError("Expected argument 'schema_name' to be a str")
        pulumi.set(__self__, "schema_name", schema_name)
        if sources and not isinstance(sources, list):
            raise TypeError("Expected argument 'sources' to be a list")
        pulumi.set(__self__, "sources", sources)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[str]:
        """
        Limit sources to a specific database
        """
        return pulumi.get(self, "database_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def region(self) -> str:
        """
        The region in which the resource is located.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[str]:
        """
        Limit sources to a specific schema within a specific database
        """
        return pulumi.get(self, "schema_name")

    @property
    @pulumi.getter
    def sources(self) -> Sequence['outputs.GetSourcesSourceResult']:
        """
        The sources in the account
        """
        return pulumi.get(self, "sources")


class AwaitableGetSourcesResult(GetSourcesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSourcesResult(
            database_name=self.database_name,
            id=self.id,
            region=self.region,
            schema_name=self.schema_name,
            sources=self.sources)


def get_sources(database_name: Optional[str] = None,
                region: Optional[str] = None,
                schema_name: Optional[str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSourcesResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_materialize as materialize

    all = materialize.get_sources()
    materialize = materialize.get_sources(database_name="materialize")
    materialize_schema = materialize.get_sources(database_name="materialize",
        schema_name="schema")
    ```


    :param str database_name: Limit sources to a specific database
    :param str region: The region in which the resource is located.
    :param str schema_name: Limit sources to a specific schema within a specific database
    """
    __args__ = dict()
    __args__['databaseName'] = database_name
    __args__['region'] = region
    __args__['schemaName'] = schema_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('materialize:index/getSources:GetSources', __args__, opts=opts, typ=GetSourcesResult).value

    return AwaitableGetSourcesResult(
        database_name=pulumi.get(__ret__, 'database_name'),
        id=pulumi.get(__ret__, 'id'),
        region=pulumi.get(__ret__, 'region'),
        schema_name=pulumi.get(__ret__, 'schema_name'),
        sources=pulumi.get(__ret__, 'sources'))


@_utilities.lift_output_func(get_sources)
def get_sources_output(database_name: Optional[pulumi.Input[Optional[str]]] = None,
                       region: Optional[pulumi.Input[Optional[str]]] = None,
                       schema_name: Optional[pulumi.Input[Optional[str]]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSourcesResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_materialize as materialize

    all = materialize.get_sources()
    materialize = materialize.get_sources(database_name="materialize")
    materialize_schema = materialize.get_sources(database_name="materialize",
        schema_name="schema")
    ```


    :param str database_name: Limit sources to a specific database
    :param str region: The region in which the resource is located.
    :param str schema_name: Limit sources to a specific schema within a specific database
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['SystemParameterArgs', 'SystemParameter']

@pulumi.input_type
class SystemParameterArgs:
    def __init__(__self__, *,
                 value: pulumi.Input[str],
                 name: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a SystemParameter resource.
        :param pulumi.Input[str] value: The value to set for the system parameter.
        :param pulumi.Input[str] name: The name of the system parameter.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        """
        pulumi.set(__self__, "value", value)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[str]:
        """
        The value to set for the system parameter.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[str]):
        pulumi.set(self, "value", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the system parameter.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _SystemParameterState:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SystemParameter resources.
        :param pulumi.Input[str] name: The name of the system parameter.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] value: The value to set for the system parameter.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the system parameter.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[str]]:
        """
        The value to set for the system parameter.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "value", value)


class SystemParameter(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a system parameter in Materialize.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        # ALTER SYSTEM SET cluster TO 'cluster_name';
        example_system_parameter = materialize.SystemParameter("exampleSystemParameter", value="cluster_name")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: The name of the system parameter.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] value: The value to set for the system parameter.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SystemParameterArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a system parameter in Materialize.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        # ALTER SYSTEM SET cluster TO 'cluster_name';
        example_system_parameter = materialize.SystemParameter("exampleSystemParameter", value="cluster_name")
        ```

        :param str resource_name: The name of the resource.
        :param SystemParameterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SystemParameterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SystemParameterArgs.__new__(SystemParameterArgs)

            __props__.__dict__["name"] = name
            __props__.__dict__["region"] = region
            if value is None and not opts.urn:
                raise TypeError("Missing required property 'value'")
            __props__.__dict__["value"] = value
        super(SystemParameter, __self__).__init__(
            'materialize:index/systemParameter:SystemParameter',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            name: Optional[pulumi.Input[str]] = None,
            region: Optional[pulumi.Input[str]] = None,
            value: Optional[pulumi.Input[str]] = None) -> 'SystemParameter':
        """
        Get an existing SystemParameter resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: The name of the system parameter.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] value: The value to set for the system parameter.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SystemParameterState.__new__(_SystemParameterState)

        __props__.__dict__["name"] = name
        __props__.__dict__["region"] = region
        __props__.__dict__["value"] = value
        return SystemParameter(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the system parameter.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[str]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter
    def value(self) -> pulumi.Output[str]:
        """
        The value to set for the system parameter.
        """
        return pulumi.get(self, "value")

